@@ -38,10 +38,3 @@ class UnsupportedBodyType(Exception):
     """
     def __str__(self):
         return "This type of body is not supported for this API call."
-
-class UnsupportedArgument(Exception):
-    """
-    If attempting to use an unsupported argument
-    """
-    def __str__(self):
-        return "This function does not currently support this argument."
\ No newline at end of file
